AsimIcon class

Constructors

AsimIcon()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getIconAction(dynamic icon) String
getIconCommunication(dynamic icon) String
getIconEntertainment(dynamic icon) String
getIconMessages(dynamic icon) String
getIconShopping(dynamic icon) String
getIconUI(dynamic icon) String