DSMargin class

Constructors

DSMargin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

Margin_0 double
Margin: 0
getter/setter pair
Margin_16 double
Margin: 16
getter/setter pair
Margin_24 double
Margin: 24
getter/setter pair
Margin_32 double
Margin: 32
getter/setter pair
Margin_8 double
Margin: 8
getter/setter pair