IconCommunication class

Constructors

IconCommunication()

Properties

alarmClock String
no setter
alarmClockFill String
no setter
bubbleChat String
no setter
bubbleChatFill String
no setter
call String
no setter
callFill String
no setter
calling String
no setter
callingFill String
no setter
callOff String
no setter
callOffFill String
no setter
camera String
no setter
cameraFill String
no setter
cameraOff String
no setter
cameraOffFill String
no setter
customerService String
no setter
customerServiceFill String
no setter
envelope String
no setter
envelopeFill String
no setter
faceId String
no setter
faceIdFill String
no setter
folder String
no setter
folderFill String
no setter
forward String
no setter
forwardFill String
no setter
hashCode int
The hash code for this object.
no setterinherited
headphone String
no setter
headphoneFill String
no setter
list String
no setter
listFill String
no setter
micro String
no setter
microFill String
no setter
microOff String
no setter
microOffFill String
no setter
missedCall String
no setter
missedCallFill String
no setter
photo String
no setter
photoFill String
no setter
pin String
no setter
pinFill String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
send String
no setter
sendFill String
no setter
speakerDown String
no setter
speakerDownFill String
no setter
speakerOff String
no setter
speakerOffFill String
no setter
speakerUp String
no setter
speakerUpFill String
no setter
user String
no setter
user2 String
no setter
user2Fill String
no setter
user3 String
no setter
user3Fill String
no setter
userAdd String
no setter
userAddFill String
no setter
userFill String
no setter
video String
no setter
videoFill String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited